@@ -84,18 +84,19 @@
 #' <https://www.soa.org/49378a/globalassets/assets/files/research/experience-study-calculations.pdf>
 #'
 #' @export
-expose <- function(.data,
-                   end_date,
-                   start_date = as.Date("1900-01-01"),
-                   target_status = NULL,
-                   cal_expo = FALSE,
-                   expo_length = c("year", "quarter", "month", "week"),
-                   col_pol_num = "pol_num",
-                   col_status = "status",
-                   col_issue_date = "issue_date",
-                   col_term_date = "term_date",
-                   default_status) {
-
+expose <- function(
+  .data,
+  end_date,
+  start_date = as.Date("1900-01-01"),
+  target_status = NULL,
+  cal_expo = FALSE,
+  expo_length = c("year", "quarter", "month", "week"),
+  col_pol_num = "pol_num",
+  col_status = "status",
+  col_issue_date = "issue_date",
+  col_term_date = "term_date",
+  default_status
+) {
   end_date <- as.Date(end_date)
   start_date <- as.Date(start_date)
 
@@ -115,10 +116,12 @@ expose <- function(.data,
 
   # column renames and name conflicts
   .data <- .data |>
-    rename(pol_num = {{col_pol_num}},
-           status = {{col_status}},
-           issue_date = {{col_issue_date}},
-           term_date = {{col_term_date}}) |>
+    rename(
+      pol_num = {{ col_pol_num }},
+      status = {{ col_status }},
+      issue_date = {{ col_issue_date }},
+      term_date = {{ col_term_date }}
+    ) |>
     .expo_name_conflict(cal_expo, expo_length) |>
     # convert to dates if needed
     mutate(dplyr::across(c(issue_date, term_date), .convert_date))
@@ -128,19 +131,20 @@ expose <- function(.data,
   if (n_term_dates != sum(!is.na(.data$term_date))) {
     rlang::abort(c(
       "Bad termination date formats were detected.",
-      i = "Make sure all dates are in YYYY-MM-DD format.")
-    )
+      i = "Make sure all dates are in YYYY-MM-DD format."
+    ))
   }
 
   # set up statuses
-  if (!is.factor(.data$status)) .data$status <- factor(.data$status)
+  if (!is.factor(.data$status)) {
+    .data$status <- factor(.data$status)
+  }
 
   if (missing(default_status)) {
     default_status <- most_common(.data$status)
   } else {
     status_levels <- union(levels(.data$status), default_status)
-    default_status <- factor(default_status,
-                             levels = status_levels)
+    default_status <- factor(default_status, levels = status_levels)
     levels(.data$status) <- status_levels
   }
 
@@ -152,26 +156,26 @@ expose <- function(.data,
 
   # pre-exposure updates
   res <- .data |>
-    filter(issue_date < end_date,
-           is.na(term_date) | term_date > start_date) |>
+    filter(issue_date < end_date, is.na(term_date) | term_date > start_date) |>
     mutate(
-      term_date = dplyr::if_else(term_date > end_date,
-                                 as.Date(NA), term_date),
+      term_date = dplyr::if_else(term_date > end_date, as.Date(NA), term_date),
       status = dplyr::if_else(is.na(term_date), default_status, status),
-      last_date = pmin(term_date, end_date, na.rm = TRUE))
+      last_date = pmin(term_date, end_date, na.rm = TRUE)
+    )
 
   if (cal_expo) {
     res <- res |>
       mutate(
         first_date = pmax(issue_date, start_date),
         cal_b = cal_floor(first_date),
-        rep_n = clock::date_count_between(cal_b, last_date,
-                                          expo_length) + 1L)
+        rep_n = clock::date_count_between(cal_b, last_date, expo_length) + 1L
+      )
   } else {
     res <- res |>
       mutate(
-        rep_n = clock::date_count_between(issue_date, last_date,
-                                          expo_length) + 1L)
+        rep_n = clock::date_count_between(issue_date, last_date, expo_length) +
+          1L
+      )
   }
 
   # apply exposures
@@ -183,27 +187,34 @@ expose <- function(.data,
     mutate(
       last_per = .time == rep_n,
       status = dplyr::if_else(last_per, status, default_status),
-      term_date = dplyr::if_else(last_per, term_date, as.Date(NA)))
+      term_date = dplyr::if_else(last_per, term_date, as.Date(NA))
+    )
 
   if (cal_expo) {
     res <- res |>
-      mutate(first_per = .time == 1,
-             cal_e = add_period(cal_b, .time) - 1L,
-             cal_b = add_period(cal_b, .time - 1L),
-             exposure = dplyr::case_when(
-               status %in% target_status ~ 1,
-               first_per & last_per ~ cal_frac(last_date) -
-                 cal_frac(first_date, 1),
-               first_per ~ 1 - cal_frac(first_date, 1),
-               last_per ~ cal_frac(last_date),
-               TRUE ~ 1)
+      mutate(
+        first_per = .time == 1,
+        cal_e = add_period(cal_b, .time) - 1L,
+        cal_b = add_period(cal_b, .time - 1L),
+        exposure = dplyr::case_when(
+          status %in% target_status ~ 1,
+          first_per & last_per ~
+            cal_frac(last_date) -
+              cal_frac(first_date, 1),
+          first_per ~ 1 - cal_frac(first_date, 1),
+          last_per ~ cal_frac(last_date),
+          TRUE ~ 1
+        )
       ) |>
-      select(-rep_n, -first_date, -last_date, -first_per, -last_per,
-             -.time) |>
+      select(-rep_n, -first_date, -last_date, -first_per, -last_per, -.time) |>
       relocate(cal_e, .after = cal_b) |>
       dplyr::rename_with(.fn = rename_col, .cols = cal_b, prefix = "cal") |>
-      dplyr::rename_with(.fn = rename_col, .cols = cal_e, prefix = "cal",
-                         suffix = "_end")
+      dplyr::rename_with(
+        .fn = rename_col,
+        .cols = cal_e,
+        prefix = "cal",
+        suffix = "_end"
+      )
   } else {
     res <- res |>
       mutate(
@@ -211,27 +222,40 @@ expose <- function(.data,
         cal_e = add_period(issue_date, .time) - 1L,
         exposure = dplyr::if_else(
           last_per & !status %in% target_status,
-          as.integer((last_date - cal_b + 1))  /
+          as.integer((last_date - cal_b + 1)) /
             as.integer(cal_e - cal_b + 1),
-          1),
+          1
+        ),
         # exposure = 0 is possible if exactly 1 period has elapsed. replace these with 1's
         exposure = dplyr::if_else(exposure == 0, 1, exposure)
       ) |>
       select(-last_per, -last_date, -rep_n) |>
       filter(between(cal_b, start_date, end_date)) |>
       dplyr::rename_with(.fn = rename_col, .cols = .time, prefix = "pol") |>
-      dplyr::rename_with(.fn = rename_col, .cols = cal_b, prefix = "pol_date") |>
-      dplyr::rename_with(.fn = rename_col, .cols = cal_e, prefix = "pol_date",
-                         suffix = "_end")
-
-
+      dplyr::rename_with(
+        .fn = rename_col,
+        .cols = cal_b,
+        prefix = "pol_date"
+      ) |>
+      dplyr::rename_with(
+        .fn = rename_col,
+        .cols = cal_e,
+        prefix = "pol_date",
+        suffix = "_end"
+      )
   }
 
   # set up S3 object
-  new_exposed_df(res, end_date, start_date,
-                 target_status, cal_expo, expo_length,
-                 trx_types = NULL, default_status)
-
+  new_exposed_df(
+    res,
+    end_date,
+    start_date,
+    target_status,
+    cal_expo,
+    expo_length,
+    trx_types = NULL,
+    default_status
+  )
 }
 
 
@@ -292,7 +316,8 @@ year_frac <- function(x, .offset = 0) {
 quarter_frac <- function(x, .offset = 0) {
   xday <- clock::as_year_quarter_day(x) |> clock::get_day()
   qdays <- (clock::date_group(x, "month", n = 3) |>
-              clock::add_quarters(1, invalid = "previous") - 1L) |>
+    clock::add_quarters(1, invalid = "previous") -
+    1L) |>
     clock::as_year_quarter_day() |>
     clock::get_day()
   (xday - .offset) / qdays
@@ -301,7 +326,8 @@ quarter_frac <- function(x, .offset = 0) {
 month_frac <- function(x, .offset = 0) {
   xday <- clock::get_day(x)
   mdays <- (clock::date_group(x, "month") |>
-              clock::add_months(1, invalid = "previous") - 1L) |>
+    clock::add_months(1, invalid = "previous") -
+    1L) |>
     clock::get_day()
   (xday - .offset) / mdays
 }
@@ -311,11 +337,13 @@ week_frac <- function(x, .offset = 0) {
 }
 
 cal_frac <- function(expo_length) {
-  switch(expo_length,
-         "year" = year_frac,
-         "quarter" = quarter_frac,
-         "month" = month_frac,
-         'week' = week_frac)
+  switch(
+    expo_length,
+    "year" = year_frac,
+    "quarter" = quarter_frac,
+    "month" = month_frac,
+    'week' = week_frac
+  )
 }
 
 # helper functions for calendar year flooring
@@ -337,27 +365,32 @@ week_floor <- function(x) {
 }
 
 cal_floor <- function(expo_length) {
-  switch(expo_length,
-         "year" = year_floor,
-         "quarter" = quarter_floor,
-         "month" = month_floor,
-         'week' = week_floor)
+  switch(
+    expo_length,
+    "year" = year_floor,
+    "quarter" = quarter_floor,
+    "month" = month_floor,
+    'week' = week_floor
+  )
 }
 
 # helper function for adding period
 add_period <- function(expo_length) {
-  fun <- switch(expo_length,
-                "year" = clock::add_years,
-                "quarter" = clock::add_quarters,
-                "month" = clock::add_months,
-                'week' = clock::add_weeks)
-  if (expo_length == "week") return(fun)
+  fun <- switch(
+    expo_length,
+    "year" = clock::add_years,
+    "quarter" = clock::add_quarters,
+    "month" = clock::add_months,
+    'week' = clock::add_weeks
+  )
+  if (expo_length == "week") {
+    return(fun)
+  }
   \(x, n) fun(x, n, invalid = "previous")
 }
 
 # helper function to handle name conflicts
 .expo_name_conflict <- function(.data, cal_expo, expo_length) {
-
   abbrev <- abbr_period(expo_length)
 
   x <- c(
@@ -370,19 +403,17 @@ add_period <- function(expo_length) {
   x <- x[x %in% names(.data)]
   .data[x] <- NULL
   if (length(x > 0)) {
-    cli::cli_warn(c(x = "`.data` contains the following conflicting columns that will be overridden: {.val {x}}.",
-                    i = "If you don't want this to happen, rename these columns prior to calling the applicable expose function."))
+    cli::cli_warn(c(
+      x = "`.data` contains the following conflicting columns that will be overridden: {.val {x}}.",
+      i = "If you don't want this to happen, rename these columns prior to calling the applicable expose function."
+    ))
   }
   .data
 }
 
 # helper function - do not export
 abbr_period <- function(x) {
-  switch(x,
-         "year" = "yr",
-         "quarter" = "qtr",
-         "month" = "mth",
-         'week' = "wk")
+  switch(x, "year" = "yr", "quarter" = "qtr", "month" = "mth", 'week' = "wk")
 }
 
 # determine the most common status
@@ -396,7 +427,9 @@ is.Date <- function(x) {
 }
 
 .convert_date <- function(x) {
-  if (is.Date(x)) return(x)
+  if (is.Date(x)) {
+    return(x)
+  }
   clock::date_parse(x, format = "%Y-%m-%d")
 }
 
@@ -404,7 +437,7 @@ is.Date <- function(x) {
   if (any(is.na(x))) {
     cli::cli_abort(c(
       "Missing values are not allowed in the `{name}` column.",
-      i = "Make sure all dates are in YYYY-MM-DD format.")
-    )
+      i = "Make sure all dates are in YYYY-MM-DD format."
+    ))
   }
 }
