@@ -42,19 +42,21 @@
 #'
 #' @export
 expose_split <- function(.data) {
-
   verify_exposed_df(.data)
   expo_type <- strsplit(attr(.data, "exposure_type"), "_")[[1]]
 
   if (expo_type[[1]] != "calendar") {
-    rlang::abort(c(x = "`.data` must contain calendar exposures.",
-                   i = "Hint: Try passing an `exposed_df` object that was created by `expose_cy()`, `expose_cq()`, `expose_cm()`, or `expose_cw()`."))
+    rlang::abort(c(
+      x = "`.data` must contain calendar exposures.",
+      i = "Hint: Try passing an `exposed_df` object that was created by `expose_cy()`, `expose_cq()`, `expose_cm()`, or `expose_cw()`."
+    ))
   }
 
   if (!is.null(attr(.data, "trx_types"))) {
-    rlang::warn(c("!" = "`.data` has transactions attached. This will lead to duplication of transactions after exposures are split.",
-                  "i" = "The appropriate order of operations is to call `add_transactions()` after `expose_split()`.")
-    )
+    rlang::warn(c(
+      "!" = "`.data` has transactions attached. This will lead to duplication of transactions after exposures are split.",
+      "i" = "The appropriate order of operations is to call `add_transactions()` after `expose_split()`."
+    ))
   }
 
   target_status <- attr(.data, "target_status")
@@ -80,8 +82,7 @@ expose_split <- function(.data) {
 
   .data <- .data |>
     # temporary generic date column names
-    rename(cal_b = !!date_cols[[1]],
-           cal_e = !!date_cols[[2]]) |>
+    rename(cal_b = !!date_cols[[1]], cal_e = !!date_cols[[2]]) |>
     mutate(
       pol_yr = clock::get_year(cal_b) - clock::get_year(issue_date),
       anniv = add_years(issue_date, pol_yr),
@@ -95,64 +96,80 @@ expose_split <- function(.data) {
 
   pre_anniv <- .data |>
     filter(split) |>
-    mutate(piece = 1L,
-           next_anniv = anniv,
-           cal_e = pmin(end_date, next_anniv - 1),
-           exposure = pmin(h, v) - b
+    mutate(
+      piece = 1L,
+      next_anniv = anniv,
+      cal_e = pmin(end_date, next_anniv - 1),
+      exposure = pmin(h, v) - b
     )
 
   post_anniv <- .data |>
-    mutate(piece = 2L,
-           cal_b = dplyr::if_else(split, pmax(anniv, start_date), cal_b),
-           pol_yr = pol_yr + (cal_b >= anniv),
-           exposure = v - pmax(h, b),
-           next_anniv = add_years(issue_date, pol_yr)
+    mutate(
+      piece = 2L,
+      cal_b = dplyr::if_else(split, pmax(anniv, start_date), cal_b),
+      pol_yr = pol_yr + (cal_b >= anniv),
+      exposure = v - pmax(h, b),
+      next_anniv = add_years(issue_date, pol_yr)
     )
 
   .data <- dplyr::bind_rows(pre_anniv, post_anniv) |>
-    filter(cal_b <= cal_e,
-           is.na(term_date) | term_date >= cal_b) |>
-    mutate(anniv = add_years(issue_date, pol_yr - 1L),
-           term_date = dplyr::if_else(between(term_date, cal_b, cal_e),
-                                      term_date, as.Date(NA)),
-           status = dplyr::if_else(is.na(term_date),
-                                   factor(default_status,
-                                          levels = levels(.data$status)),
-                                   status),
-           claims = status %in% target_status,
-           exposure_cal = dplyr::case_when(
-             claims ~ dplyr::if_else(piece == 1 | cal_b == issue_date |
-                                       cal_b == start_date,
-                                     1, 1 - (h - b)),
-             is.na(term_date) ~ exposure,
-             piece == 1 ~ v - b,
-             .default = v - pmax(h, b)
-           ),
-           exposure_pol = dplyr::if_else(
-             claims,
-             1 - pol_frac(cal_b - 1L,
-                          anniv,
-                          next_anniv - 1L),
-             pol_frac(pmin(cal_e, term_date, na.rm = TRUE),
-                      anniv,
-                      next_anniv - 1L,
-                      cal_b - 1L)
-           )
+    filter(cal_b <= cal_e, is.na(term_date) | term_date >= cal_b) |>
+    mutate(
+      anniv = add_years(issue_date, pol_yr - 1L),
+      term_date = dplyr::if_else(
+        between(term_date, cal_b, cal_e),
+        term_date,
+        as.Date(NA)
+      ),
+      status = dplyr::if_else(
+        is.na(term_date),
+        factor(default_status, levels = levels(.data$status)),
+        status
+      ),
+      claims = status %in% target_status,
+      exposure_cal = dplyr::case_when(
+        claims ~
+          dplyr::if_else(
+            piece == 1 | cal_b == issue_date | cal_b == start_date,
+            1,
+            1 - (h - b)
+          ),
+        is.na(term_date) ~ exposure,
+        piece == 1 ~ v - b,
+        .default = v - pmax(h, b)
+      ),
+      exposure_pol = dplyr::if_else(
+        claims,
+        1 - pol_frac(cal_b - 1L, anniv, next_anniv - 1L),
+        pol_frac(
+          pmin(cal_e, term_date, na.rm = TRUE),
+          anniv,
+          next_anniv - 1L,
+          cal_b - 1L
+        )
+      )
     ) |>
     arrange(pol_num, cal_b, piece) |>
-    select(-b, -h, -v, -split, -anniv, -next_anniv,
-           -claims, -exposure, -piece) |>
+    select(
+      -b,
+      -h,
+      -v,
+      -split,
+      -anniv,
+      -next_anniv,
+      -claims,
+      -exposure,
+      -piece
+    ) |>
     relocate(pol_yr, .after = cal_e) |>
     # restore date column names
-    rename(!!date_cols[[1]] := cal_b,
-           !!date_cols[[2]] := cal_e)
+    rename(!!date_cols[[1]] := cal_b, !!date_cols[[2]] := cal_e)
 
   # update exposure type and update class
   class(.data) <- c("split_exposed_df", class(.data))
   attr(.data, "exposure_type") <- paste0("split_", expo_length)
 
   .data
-
 }
 
 #' @rdname expose_split
@@ -165,10 +182,14 @@ is_split_exposed_df <- function(x) {
 # This internal function sends an error if a `split_exposed_df` is passed
 # without clarifying which exposure basis should be used.
 check_split_expose_basis <- function(dat, col_exposure) {
-  if (is_split_exposed_df(dat) &&
-      !col_exposure %in% c("exposure_cal", "exposure_pol")) {
-    rlang::abort(c(x = "A `split_exposed_df` was passed without clarifying which exposure basis should be used to summarize results.",
-                   i = 'Pass "exposure_pol" to `col_exposure` for policy year exposures.',
-                   i = 'Pass "exposure_cal" to `col_exposure` for calendar exposures.'))
+  if (
+    is_split_exposed_df(dat) &&
+      !col_exposure %in% c("exposure_cal", "exposure_pol")
+  ) {
+    rlang::abort(c(
+      x = "A `split_exposed_df` was passed without clarifying which exposure basis should be used to summarize results.",
+      i = 'Pass "exposure_pol" to `col_exposure` for policy year exposures.',
+      i = 'Pass "exposure_cal" to `col_exposure` for calendar exposures.'
+    ))
   }
 }
