@@ -62,15 +62,24 @@
 #' @name autoplot_exp
 #' @rdname autoplot_exp
 #' @export
-autoplot.exp_df <- function(object, ..., x = NULL, y = NULL, color = NULL,
-                            mapping, second_axis = FALSE, second_y = NULL,
-                            scales = "fixed",
-                            geoms = c("lines", "bars", "points"),
-                            y_labels = scales::label_percent(accuracy = 0.1),
-                            second_y_labels = scales::label_comma(
-                              accuracy = 1),
-                            y_log10 = FALSE, conf_int_bars = FALSE) {
-
+autoplot.exp_df <- function(
+  object,
+  ...,
+  x = NULL,
+  y = NULL,
+  color = NULL,
+  mapping,
+  second_axis = FALSE,
+  second_y = NULL,
+  scales = "fixed",
+  geoms = c("lines", "bars", "points"),
+  y_labels = scales::label_percent(accuracy = 0.1),
+  second_y_labels = scales::label_comma(
+    accuracy = 1
+  ),
+  y_log10 = FALSE,
+  conf_int_bars = FALSE
+) {
   y <- rlang::enexpr(y)
   y <- if (is.null(y)) rlang::expr(q_obs) else y
 
@@ -81,23 +90,44 @@ autoplot.exp_df <- function(object, ..., x = NULL, y = NULL, color = NULL,
     second_y
   }
 
-  plot_experience(object, rlang::enexpr(x), y,
-                  rlang::enexpr(color), mapping, second_axis, second_y,
-                  scales, geoms, y_labels, second_y_labels, rlang::enquos(...),
-                  y_log10, conf_int_bars)
+  plot_experience(
+    object,
+    rlang::enexpr(x),
+    y,
+    rlang::enexpr(color),
+    mapping,
+    second_axis,
+    second_y,
+    scales,
+    geoms,
+    y_labels,
+    second_y_labels,
+    rlang::enquos(...),
+    y_log10,
+    conf_int_bars
+  )
 }
 
 #' @rdname autoplot_exp
 #' @export
-autoplot.trx_df <- function(object, ..., x = NULL, y = NULL, color = NULL,
-                            mapping, second_axis = FALSE, second_y = NULL,
-                            scales = "fixed",
-                            geoms = c("lines", "bars", "points"),
-                            y_labels = scales::label_percent(accuracy = 0.1),
-                            second_y_labels = scales::label_comma(
-                              accuracy = 1),
-                            y_log10 = FALSE, conf_int_bars = FALSE) {
-
+autoplot.trx_df <- function(
+  object,
+  ...,
+  x = NULL,
+  y = NULL,
+  color = NULL,
+  mapping,
+  second_axis = FALSE,
+  second_y = NULL,
+  scales = "fixed",
+  geoms = c("lines", "bars", "points"),
+  y_labels = scales::label_percent(accuracy = 0.1),
+  second_y_labels = scales::label_comma(
+    accuracy = 1
+  ),
+  y_log10 = FALSE,
+  conf_int_bars = FALSE
+) {
   y <- rlang::enexpr(y)
   y <- if (is.null(y)) rlang::expr(trx_util) else y
 
@@ -113,25 +143,40 @@ autoplot.trx_df <- function(object, ..., x = NULL, y = NULL, color = NULL,
     facets <- c(rlang::expr(trx_type), groups(object)[-(1:2)])
   }
 
-  plot_experience(object, rlang::enexpr(x), y,
-                  rlang::enexpr(color), mapping, second_axis, second_y,
-                  scales, geoms, y_labels, second_y_labels, facets,
-                  y_log10, conf_int_bars)
+  plot_experience(
+    object,
+    rlang::enexpr(x),
+    y,
+    rlang::enexpr(color),
+    mapping,
+    second_axis,
+    second_y,
+    scales,
+    geoms,
+    y_labels,
+    second_y_labels,
+    facets,
+    y_log10,
+    conf_int_bars
+  )
 }
 
 plot_experience <- function(
-    object, x = NULL, y = NULL, color = NULL,
-    mapping,
-    second_axis = FALSE,
-    second_y = NULL,
-    scales = "fixed",
-    geoms = c("lines", "bars", "points"),
-    y_labels = scales::label_percent(accuracy = 0.1),
-    second_y_labels = scales::label_comma(accuracy = 1),
-    facets,
-    y_log10,
-    conf_int_bars = FALSE) {
-
+  object,
+  x = NULL,
+  y = NULL,
+  color = NULL,
+  mapping,
+  second_axis = FALSE,
+  second_y = NULL,
+  scales = "fixed",
+  geoms = c("lines", "bars", "points"),
+  y_labels = scales::label_percent(accuracy = 0.1),
+  second_y_labels = scales::label_comma(accuracy = 1),
+  facets,
+  y_log10,
+  conf_int_bars = FALSE
+) {
   .groups <- groups(object)
   if (length(.groups) == 0) {
     .groups <- list(rlang::parse_expr("All"))
@@ -152,9 +197,16 @@ plot_experience <- function(
   if (missing(mapping)) {
     x <- auto_aes(x, 1)
     color <- auto_aes(color, 2)
-    if (!is.null(color) && as.character(color) == ".no_color") color <- NULL
-    mapping <- ggplot2::aes(!!x, !!y, color = !!color,
-                            fill = !!color, group = !!color)
+    if (!is.null(color) && as.character(color) == ".no_color") {
+      color <- NULL
+    }
+    mapping <- ggplot2::aes(
+      !!x,
+      !!y,
+      color = !!color,
+      fill = !!color,
+      group = !!color
+    )
   }
 
   if (length(facets) == 0) {
@@ -178,33 +230,50 @@ plot_experience <- function(
     if (y_log10) {
       geom.fun <- function(...) {
         ggplot2::geom_ribbon(
-          ggplot2::aes(ymax = !!second_y,
-                       group = if (is.null(color)) 1 else !!color),
-          ..., ymin = -Inf)
+          ggplot2::aes(
+            ymax = !!second_y,
+            group = if (is.null(color)) 1 else !!color
+          ),
+          ...,
+          ymin = -Inf
+        )
       }
     } else {
       geom.fun <- function(...) {
         ggplot2::geom_area(
-          ggplot2::aes(y = !!second_y,
-                       group = if (is.null(color)) 1 else !!color),
-          ...)
+          ggplot2::aes(
+            y = !!second_y,
+            group = if (is.null(color)) 1 else !!color
+          ),
+          ...
+        )
       }
     }
-    p <- p + geom.fun(data = object |>
-                        mutate(!!second_y := !!second_y /
-                                 adj),
-                      alpha = 0.2, position = "identity") +
+    p <- p +
+      geom.fun(
+        data = object |>
+          mutate(
+            !!second_y := !!second_y /
+              adj
+          ),
+        alpha = 0.2,
+        position = "identity"
+      ) +
       ggplot2::scale_y_continuous(
-        sec.axis =
-          ggplot2::sec_axis(~ . * adj,
-                            labels = second_y_labels,
-                            name = as.character(second_y)),
+        sec.axis = ggplot2::sec_axis(
+          ~ . * adj,
+          labels = second_y_labels,
+          name = as.character(second_y)
+        ),
         labels = y_labels,
-        trans = y_trans)
+        trans = y_trans
+      )
   } else {
-    p <- p + ggplot2::scale_y_continuous(
-      labels = y_labels,
-      trans = y_trans)
+    p <- p +
+      ggplot2::scale_y_continuous(
+        labels = y_labels,
+        trans = y_trans
+      )
   }
 
   if (geoms == "lines") {
@@ -216,7 +285,6 @@ plot_experience <- function(
   }
 
   if (conf_int_bars) {
-
     conf_int <- attr(object, "xp_params")$conf_int
     y_chr <- rlang::as_name(p$mapping$y)
     y_min_max <- paste0(y_chr, c("_upper", "_lower"))
@@ -224,26 +292,32 @@ plot_experience <- function(
     if (is.null(conf_int) || !conf_int) {
       conf_int_warning()
     } else {
-
       if (all(y_min_max %in% names(object))) {
         y_min_max <- rlang::syms(y_min_max)
-        p <- p + ggplot2::geom_errorbar(ggplot2::aes(
-          ymin = !!y_min_max[[1]], ymax = !!y_min_max[[2]]))
-
+        p <- p +
+          ggplot2::geom_errorbar(ggplot2::aes(
+            ymin = !!y_min_max[[1]],
+            ymax = !!y_min_max[[2]]
+          ))
       } else {
-        rlang::warn(c("Confidence intervals are not available for the selected y-variable."))
+        rlang::warn(c(
+          "Confidence intervals are not available for the selected y-variable."
+        ))
       }
     }
   }
 
-  if (is.null(facets)) return(p)
+  if (is.null(facets)) {
+    return(p)
+  }
   p + ggplot2::facet_wrap(ggplot2::vars(!!!facets), scales = scales)
-
 }
 
 # This internal function provides a common warning that is used by multiple
 # functions.
 conf_int_warning <- function() {
-  rlang::warn(c("*" = "`object` has no confidence intervals.",
-                "i" = "Pass `conf_int = TRUE` to `exp_stats()` or `trx_stats()` to calculate confidence intervals."))
+  rlang::warn(c(
+    "*" = "`object` has no confidence intervals.",
+    "i" = "Pass `conf_int = TRUE` to `exp_stats()` or `trx_stats()` to calculate confidence intervals."
+  ))
 }
