@@ -8,67 +8,83 @@ test_that("is_exposed_df works", {
 expo2 <- as.data.frame(expo)
 
 test_that("as_exposed_df works", {
-
-
   expo3 <- as_exposed_df(expo2, end_date = "2022-12-31")
   expo4 <- expo2 |>
     rename(pnum = pol_num)
   expo5 <- expo4 |>
-    rename(pstat = status,
-           expo = exposure,
-           py = pol_yr,
-           start = pol_date_yr,
-           end = pol_date_yr_end)
+    rename(
+      pstat = status,
+      expo = exposure,
+      py = pol_yr,
+      start = pol_date_yr,
+      end = pol_date_yr_end
+    )
 
-  expect_error(as_exposed_df(data.frame(a = 1:3), Sys.Date()),
-               regexp = "The following columns are missing")
+  expect_error(
+    as_exposed_df(data.frame(a = 1:3), Sys.Date()),
+    regexp = "The following columns are missing"
+  )
 
   expect_true(is_exposed_df(as_exposed_df(expo)))
 
   expect_false(is_exposed_df(expo2))
-  expect_error(as_exposed_df(expo2, end_date = "2022-12-31",
-                             expo_length = "yr"),
-               regexp = "`expo_length` must be one of")
+  expect_error(
+    as_exposed_df(expo2, end_date = "2022-12-31", expo_length = "yr"),
+    regexp = "`expo_length` must be one of"
+  )
 
   expect_true(is_exposed_df(expo3))
 
-  expect_error(as_exposed_df(expo4,
-                             regexp = "The following columns are missing"))
-  expect_no_error(as_exposed_df(expo4, end_date = "2022-12-31",
-                                col_pol_num = "pnum"))
-  expect_no_error(as_exposed_df(expo5, end_date = "2022-12-31",
-                                col_pol_num = "pnum",
-                                col_status = "pstat",
-                                col_exposure = "expo",
-                                col_pol_per = "py",
-                                cols_dates = c("start", "end")))
+  expect_error(as_exposed_df(
+    expo4,
+    regexp = "The following columns are missing"
+  ))
+  expect_no_error(as_exposed_df(
+    expo4,
+    end_date = "2022-12-31",
+    col_pol_num = "pnum"
+  ))
+  expect_no_error(as_exposed_df(
+    expo5,
+    end_date = "2022-12-31",
+    col_pol_num = "pnum",
+    col_status = "pstat",
+    col_exposure = "expo",
+    col_pol_per = "py",
+    cols_dates = c("start", "end")
+  ))
 
   expect_error(as_exposed_df(1), regexp = "`x` must be a data frame.")
-
 })
 
 test_that("as_exposed_df works with transactions", {
-
   expo6 <- expo2 |>
     mutate(
       trx_n_A = 1,
       trx_amt_A = 2,
       trx_n_B = 3,
-      trx_amt_B = 4)
+      trx_amt_B = 4
+    )
 
   expect_no_error(as_exposed_df(expo6, "2022-12-31", trx_types = c("A", "B")))
-  expect_error(as_exposed_df(expo6, "2022-12-31", trx_types = c("A", "C")),
-               regexp = "The following columns are missing")
+  expect_error(
+    as_exposed_df(expo6, "2022-12-31", trx_types = c("A", "C")),
+    regexp = "The following columns are missing"
+  )
 
   expo7 <- expo6 |>
-    rename(n_A = trx_n_A, n_B = trx_n_B,
-           amt_A = trx_amt_A, amt_B = trx_amt_B)
-  expect_error(as_exposed_df(expo7, "2022-12-31", trx_types = c("A", "B")),
-               regexp = "The following columns are missing")
-  expect_no_error(as_exposed_df(expo7, "2022-12-31", trx_types = c("A", "B"),
-                                col_trx_n_ = "n_",
-                                col_trx_amt_ = "amt_"))
-
+    rename(n_A = trx_n_A, n_B = trx_n_B, amt_A = trx_amt_A, amt_B = trx_amt_B)
+  expect_error(
+    as_exposed_df(expo7, "2022-12-31", trx_types = c("A", "B")),
+    regexp = "The following columns are missing"
+  )
+  expect_no_error(as_exposed_df(
+    expo7,
+    "2022-12-31",
+    trx_types = c("A", "B"),
+    col_trx_n_ = "n_",
+    col_trx_amt_ = "amt_"
+  ))
 })
 
 test_that("exposed_df class persists after grouping and ungrouping", {
@@ -84,12 +100,20 @@ test_that("exposed_df casting and coercion works with tibble and data.frame", {
 
   expo8 <- dplyr::bind_rows(expo, expo)
   expect_s3_class(expo8, "exposed_df")
-  expect_identical(attr(expo8, "target_status"), attr(expo8, "target_status") |> unique())
+  expect_identical(
+    attr(expo8, "target_status"),
+    attr(expo8, "target_status") |> unique()
+  )
 
   expo9 <- vctrs::vec_rbind(
     expo,
-    expose(toy_census, "2022-12-31", start_date = "1890-01-01",
-           target_status = "Death"))
+    expose(
+      toy_census,
+      "2022-12-31",
+      start_date = "1890-01-01",
+      target_status = "Death"
+    )
+  )
 
   expect_identical(attr(expo9, "end_date"), as.Date("2022-12-31"))
   expect_identical(attr(expo9, "start_date"), as.Date("1890-01-01"))
@@ -97,11 +121,9 @@ test_that("exposed_df casting and coercion works with tibble and data.frame", {
 
   expo10 <- expose_cy(toy_census, "2020-12-31")
   expect_error(dplyr::bind_rows(expo, expo10))
-
 })
 
 test_that("exposed_df persists in a grouped and ungrouped context after using dplyr verbs", {
-
   # rename, relocate
   grouped <- expo |> mutate(x = ifelse(pol_num == 1, "A", "B")) |> group_by(x)
 
@@ -127,7 +149,10 @@ test_that("exposed_df persists in a grouped and ungrouped context after using dp
   expect_s3_class(left_join(expo, join_frame, by = "pol_num"), "exposed_df")
   expect_s3_class(left_join(grouped, join_frame, by = "pol_num"), "exposed_df")
   expect_s3_class(right_join(expo, join_frame, by = "pol_num"), "exposed_df")
-  expect_s3_class(right_join(grouped, join_frame, by = "pol_num", multiple = "all"), "exposed_df")
+  expect_s3_class(
+    right_join(grouped, join_frame, by = "pol_num", multiple = "all"),
+    "exposed_df"
+  )
   expect_s3_class(inner_join(expo, join_frame, by = "pol_num"), "exposed_df")
   expect_s3_class(inner_join(grouped, join_frame, by = "pol_num"), "exposed_df")
   expect_s3_class(full_join(expo, join_frame, by = "pol_num"), "exposed_df")
@@ -136,18 +161,19 @@ test_that("exposed_df persists in a grouped and ungrouped context after using dp
   expect_s3_class(semi_join(grouped, join_frame, by = "pol_num"), "exposed_df")
   expect_s3_class(anti_join(expo, join_frame, by = "pol_num"), "exposed_df")
   expect_s3_class(anti_join(grouped, join_frame, by = "pol_num"), "exposed_df")
-
 })
 
 test_that("as_exposed_df default_status works", {
-
-  expect_equal(as_exposed_df(expo2, "2022-12-31") |> attr("default_status"),
-               "Active")
-  expect_equal(as_exposed_df(expo2, "2022-12-31", default_status = "Inforce") |>
-                 attr("default_status"),
-               "Inforce")
+  expect_equal(
+    as_exposed_df(expo2, "2022-12-31") |> attr("default_status"),
+    "Active"
+  )
+  expect_equal(
+    as_exposed_df(expo2, "2022-12-31", default_status = "Inforce") |>
+      attr("default_status"),
+    "Inforce"
+  )
   expect_equal(attr(expo, "default_status"), "Active")
-
 })
 
 
@@ -171,22 +197,33 @@ test_that("split_exposed_df class persists after grouping and ungrouping", {
 })
 
 test_that("split_exposed_df casting and coercion works with tibble and data.frame", {
-  expect_s3_class(dplyr::bind_rows(split, data.frame(x = 1)),
-                  "split_exposed_df")
-  expect_s3_class(dplyr::bind_rows(split, tibble::tibble(x = 1)),
-                  "split_exposed_df")
+  expect_s3_class(
+    dplyr::bind_rows(split, data.frame(x = 1)),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    dplyr::bind_rows(split, tibble::tibble(x = 1)),
+    "split_exposed_df"
+  )
 
   split8 <- dplyr::bind_rows(split, split)
   expect_s3_class(split8, "split_exposed_df")
-  expect_identical(attr(split8, "target_status"),
-                   attr(split8, "target_status") |>
-                     unique())
+  expect_identical(
+    attr(split8, "target_status"),
+    attr(split8, "target_status") |>
+      unique()
+  )
 
   split9 <- vctrs::vec_rbind(
     split,
-    expose_cy(toy_census, "2022-12-31", start_date = "1890-01-01",
-              target_status = "Death") |>
-      expose_split())
+    expose_cy(
+      toy_census,
+      "2022-12-31",
+      start_date = "1890-01-01",
+      target_status = "Death"
+    ) |>
+      expose_split()
+  )
 
   expect_identical(attr(split9, "end_date"), as.Date("2022-12-31"))
   expect_identical(attr(split9, "start_date"), as.Date("1890-01-01"))
@@ -194,11 +231,9 @@ test_that("split_exposed_df casting and coercion works with tibble and data.fram
 
   split10 <- expose_cq(toy_census, "2020-12-31") |> expose_split()
   expect_error(dplyr::bind_rows(split, split10))
-
 })
 
 test_that("split_exposed_df persists in a grouped and ungrouped context after using dplyr verbs", {
-
   # rename, relocate
   grouped <- split |> mutate(x = ifelse(pol_num == 1, "A", "B")) |> group_by(x)
 
@@ -218,33 +253,58 @@ test_that("split_exposed_df persists in a grouped and ungrouped context after us
   expect_s3_class(rename(split, abc = pol_num), "split_exposed_df")
   expect_s3_class(rename(grouped, abc = pol_num), "split_exposed_df")
   expect_s3_class(relocate(split, pol_num, .after = status), "split_exposed_df")
-  expect_s3_class(relocate(grouped, pol_num, .after = status),
-                  "split_exposed_df")
+  expect_s3_class(
+    relocate(grouped, pol_num, .after = status),
+    "split_exposed_df"
+  )
 
   join_frame <- data.frame(pol_num = 1, zzz = 2L)
-  expect_s3_class(left_join(split, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(left_join(grouped, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(right_join(split, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(right_join(grouped, join_frame, by = "pol_num",
-                             multiple = "all"), "split_exposed_df")
-  expect_s3_class(inner_join(split, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(inner_join(grouped, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(full_join(split, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(full_join(grouped, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(semi_join(split, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(semi_join(grouped, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(anti_join(split, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-  expect_s3_class(anti_join(grouped, join_frame, by = "pol_num"),
-                  "split_exposed_df")
-
+  expect_s3_class(
+    left_join(split, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    left_join(grouped, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    right_join(split, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    right_join(grouped, join_frame, by = "pol_num", multiple = "all"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    inner_join(split, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    inner_join(grouped, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    full_join(split, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    full_join(grouped, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    semi_join(split, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    semi_join(grouped, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    anti_join(split, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
+  expect_s3_class(
+    anti_join(grouped, join_frame, by = "pol_num"),
+    "split_exposed_df"
+  )
 })
